==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/SelectedValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescription } from "./SelectedValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectedValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedValueChangedEventArgsDescriptionMetadata.a == null) {
                SelectedValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedValueChangedEventArgsDescriptionMetadata.c(SelectedValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(SelectedValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldValue", "Date");
            a.item("NewValue", "Date");
        }
        static d(a) {
            SelectedValueChangedEventArgsDescriptionMetadata.b(a);
            a.aa("SelectedValueChangedEventArgs", () => new SelectedValueChangedEventArgsDescription());
            a.z("SelectedValueChangedEventArgs", SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectedValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectedValueChangedEventArgsDescriptionMetadata, 'SelectedValueChangedEventArgsDescriptionMetadata');
    SelectedValueChangedEventArgsDescriptionMetadata.a = null;
    return SelectedValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SelectedValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescription } from "./SelectedValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectedValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedValueChangedEventArgsDescriptionMetadata.a == null) {
                SelectedValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedValueChangedEventArgsDescriptionMetadata.c(SelectedValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(SelectedValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldValue", "Date");
            a.item("NewValue", "Date");
        }
        static d(a) {
            SelectedValueChangedEventArgsDescriptionMetadata.b(a);
            a.ac("SelectedValueChangedEventArgs", () => new SelectedValueChangedEventArgsDescription());
            a.ab("SelectedValueChangedEventArgs", SelectedValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectedValueChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectedValueChangedEventArgsDescriptionMetadata, 'SelectedValueChangedEventArgsDescriptionMetadata');
    SelectedValueChangedEventArgsDescriptionMetadata.a = null;
    return SelectedValueChangedEventArgsDescriptionMetadata;
})();
